srboo.SrbConnection

|  | ## Cheshire3 Object Model: Class SrbConnection

Module srboo :: Class SrbConnection

## Class SrbConnection
source code

Object Tree:

    object --+
             |
            SrbConnection

Instance Methods

__init__(self, host, port, domain, auth="ENCRYPT1", user="", passwd="", dn="") x.__init__(...) initializes x; see x.__class__.__doc__ for signature
disconnect(self)
open(self, name, flag='w')
create(self, name, size=-1, type="generic", resource="", path="")
create_collection(self, name)
up_collection(self)
open_collection(self, name)
delete_collection(self, recursive=0)
n_subcollections(self)
n_objects(self)
object_metadata(self, idx, type='name')
collection_name(self, idx)
walk_names(self)
walk(self)
rmrf(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

id |
collection |
resource |
host |
port |
domain |
auth |
user |
passwd |
dn |
Inherited from `object`: `__class__`

Method Details

### __init__(self, host, port, domain, auth="ENCRYPT1", user="", passwd="", dn="") (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### disconnect(self) | source code

### open(self, name, flag='w') | source code

### create(self, name, size=-1, type="generic", resource="", path="") | source code

### create_collection(self, name) | source code

### up_collection(self) | source code

### open_collection(self, name) | source code

### delete_collection(self, recursive=0) | source code

### n_subcollections(self) | source code

### n_objects(self) | source code

### object_metadata(self, idx, type='name') | source code

### collection_name(self, idx) | source code

### walk_names(self) | source code

### walk(self) | source code

### rmrf(self) | source code

Class Variable Details

    ### id Value:
        -1

    ### collection Value:
        ""

    ### resource Value:
        ""

    ### host Value:
        ""

    ### port Value:
        ""

    ### domain Value:
        ""

    ### auth Value:
        ""

    ### user Value:
        ""

    ### passwd Value:
        ""

    ### dn Value:
        ""